@@ -5,7 +5,7 @@ import traceback, sys, logging, os
 from logging.handlers import RotatingFileHandler
 logger = logging
 import threading
-
+from .ensure_resizable import ensure_user_resizable,keep_capped_across_screen_changes
 # Setup robust logging
 LOG_DIR = os.path.join(os.path.expanduser("~"), ".cache", "abstract_finder")
 LOG_FILE = os.path.join(LOG_DIR, "finder.log")
@@ -487,9 +487,12 @@ def startConsole(console_class, *args, **kwargs):
         app = QApplication(sys.argv)
 
         win = console_class(*args, **kwargs)          # 1) create the instance
+       
         get_WorkerScans(win)                          # 2) now add worker fields/methods
         attach_textedit_to_logs(win.log, tail_file=get_log_file_path())  # 3) textedit exists
 
+        ensure_user_resizable(win, initial_size=(1100, 800), min_size=(600, 400))
+        keep_capped_across_screen_changes(win, margin=8, fraction=0.95)
         # 4) make sure background threads die cleanly on process exit as well
         app.aboutToQuit.connect(win._graceful_shutdown)
 
