@@ -10,7 +10,7 @@ def update_table(self) -> None:
             item = QTableWidgetItem(val)
             item.setData(Qt.ItemDataRole.UserRole, data)
             if c == 1 and looks_unsaved(val):
-                item.setForeground(Qt.red)
+                item.setForeground(QBrush(QColor("red")))
             self.table.setItem(r, c, item)
     self.table.resizeColumnsToContents()
 
